@@ -73,7 +73,7 @@ class AdminServer(BaseServer):
         if self.shutdown_trigger_id is not None:
             if self.aws_sdb_coordination_domain is not None:
                 self.peercheckloop = task.LoopingCall(self.peerCheck)
-                self.peercheckloop.start(self.peer_check_interval/4)
+                self.peercheckloop.start(self.peer_check_interval)
         
     def shutdown(self):
         deferreds = []
