@@ -33,6 +33,7 @@ class ExecutionServer(BaseServer):
     simultaneous_jobs = 50
     querying_for_jobs = False
     reservation_update_queue = []
+    current_sql = ""
     
     def __init__(self,
             aws_access_key_id, 
@@ -221,7 +222,8 @@ class ExecutionServer(BaseServer):
             "active_requests":server_data["active_requests"],
             "pending_requests":server_data["pending_requests"],
             "current_timestamp":server_data["current_timestamp"],
-            "job_queue":len(self.job_queue)
+            "job_queue":len(self.job_queue),
+            "current_sql":self.current_sql.replace("\n", "")
         }
         if self.uuid_limits["start"] is None and self.uuid_limits["end"] is not None:
             attributes["range"] = "Start - %s" % self.uuid_limits["end"]
@@ -443,6 +445,7 @@ class ExecutionServer(BaseServer):
                 self.aws_sdb_reservation_domain, 
                 sdb_now(offset=self.time_offset),
                 uuid_limit_clause)
+        self.current_sql = sql
         LOGGER.debug("Querying SimpleDB, \"%s\"" % sql)
         d = self.sdb.select(sql)
         d.addCallback(self._queryCallback)
